summaryrefslogtreecommitdiffstats
path: root/src/running.ui.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-07-27 16:57:53 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-07-27 18:48:46 +0200
commit7c2bc4b5ce4fc1a72868aa949e9ec49fbe2e7931 (patch)
tree4655c7263ca5c64d23d10167cb459dd9cb253815 /src/running.ui.h
parent88ea2b6cd4382627fb6efca9cc54825aee881d1e (diff)
downloadtork-7c2bc4b5ce4fc1a72868aa949e9ec49fbe2e7931.tar.gz
tork-7c2bc4b5ce4fc1a72868aa949e9ec49fbe2e7931.zip
Initial TQt conversion
Diffstat (limited to 'src/running.ui.h')
-rw-r--r--src/running.ui.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/src/running.ui.h b/src/running.ui.h
index 8111ad9..f3c17b3 100644
--- a/src/running.ui.h
+++ b/src/running.ui.h
@@ -22,57 +22,57 @@
//dummy
#include "torkconfig.h"
#include <klocale.h>
-#include <qtooltip.h>
-#include <qpopupmenu.h>
+#include <ntqtooltip.h>
+#include <ntqpopupmenu.h>
#include <kdebug.h>
void Running::init()
{
- QStringList existingMaps = TorkConfig::sOCKSBindAddressMany();
- QListViewItem *tm;
- for ( QStringList::Iterator it = existingMaps.begin(); it != existingMaps.end(); ++it )
+ TQStringList existingMaps = TorkConfig::sOCKSBindAddressMany();
+ TQListViewItem *tm;
+ for ( TQStringList::Iterator it = existingMaps.begin(); it != existingMaps.end(); ++it )
{
if ((*it).isEmpty())
continue;
- QString entry = (*it).section(":",0,0);
- QString port = (*it).section(":",1,1);
+ TQString entry = (*it).section(":",0,0);
+ TQString port = (*it).section(":",1,1);
- tm = new QListViewItem(SOCKSBindAddressMany,entry,port);
+ tm = new TQListViewItem(SOCKSBindAddressMany,entry,port);
}
- QStringList existingSocksPolicies = TorkConfig::sOCKSPolicy();
+ TQStringList existingSocksPolicies = TorkConfig::sOCKSPolicy();
- for ( QStringList::Iterator it = existingSocksPolicies.begin(); it != existingSocksPolicies.end(); ++it )
+ for ( TQStringList::Iterator it = existingSocksPolicies.begin(); it != existingSocksPolicies.end(); ++it )
{
if ((*it).isEmpty())
continue;
- QString policy = (*it).section(" ",0,0);
- QString section2 = (*it).section(" ",1,1);
- QString entry = section2.section(":",0,0);
- QString port = section2.section(":",1,1);
+ TQString policy = (*it).section(" ",0,0);
+ TQString section2 = (*it).section(" ",1,1);
+ TQString entry = section2.section(":",0,0);
+ TQString port = section2.section(":",1,1);
- tm = new QListViewItem(SOCKSPolicy,policy,entry,port);
+ tm = new TQListViewItem(SOCKSPolicy,policy,entry,port);
}
}
void Running::PushAdd_clicked()
{
- new QListViewItem(SOCKSBindAddressMany,Address->text(), Port->text());
+ new TQListViewItem(SOCKSBindAddressMany,Address->text(), Port->text());
}
void Running::PushAdd2_clicked()
{
- new QListViewItem(SOCKSPolicy,Policy->currentText(),SocksAddress->text(), SocksPort->text());
+ new TQListViewItem(SOCKSPolicy,Policy->currentText(),SocksAddress->text(), SocksPort->text());
}
-void Running::SOCKSBindAddressMany_contextMenuRequested( QListViewItem *, const QPoint &point, int )
+void Running::SOCKSBindAddressMany_contextMenuRequested( TQListViewItem *, const TQPoint &point, int )
{
- QPopupMenu *menu = new QPopupMenu( SOCKSBindAddressMany );
+ TQPopupMenu *menu = new TQPopupMenu( SOCKSBindAddressMany );
menu->clear();
menu->insertItem( "Delete Entry", this,SLOT(slotDeleteEntry()) );
@@ -84,7 +84,7 @@ void Running::SOCKSBindAddressMany_contextMenuRequested( QListViewItem *, const
void Running::slotDeleteEntry( )
{
- QListViewItemIterator it(SOCKSBindAddressMany, QListViewItemIterator::Selected);
+ TQListViewItemIterator it(SOCKSBindAddressMany, TQListViewItemIterator::Selected);
while ( it.current() ) {
if (SOCKSBindAddressMany->isSelected( it.current()))
delete it.current();
@@ -94,10 +94,10 @@ void Running::slotDeleteEntry( )
}
-void Running::SOCKSPolicy_contextMenuRequested( QListViewItem *, const QPoint &point, int )
+void Running::SOCKSPolicy_contextMenuRequested( TQListViewItem *, const TQPoint &point, int )
{
- QPopupMenu *menu = new QPopupMenu( SOCKSPolicy );
+ TQPopupMenu *menu = new TQPopupMenu( SOCKSPolicy );
menu->clear();
menu->insertItem( "Delete Entry", this,SLOT(slotDeletePolicyEntry()) );
@@ -109,7 +109,7 @@ void Running::SOCKSPolicy_contextMenuRequested( QListViewItem *, const QPoint &p
void Running::slotDeletePolicyEntry( )
{
- QListViewItemIterator it(SOCKSPolicy, QListViewItemIterator::Selected);
+ TQListViewItemIterator it(SOCKSPolicy, TQListViewItemIterator::Selected);
while ( it.current() ) {
if (SOCKSPolicy->isSelected( it.current()))
delete it.current();
@@ -137,7 +137,7 @@ void Running::kcfg_CookieAuthentication_toggled( bool )
}
-void Running::kcfg_HashedControlPassword_textChanged( const QString & )
+void Running::kcfg_HashedControlPassword_textChanged( const TQString & )
{
if (! kcfg_HashedControlPassword->text().isEmpty()){
kcfg_CookieAuthentication->setEnabled(false);
@@ -151,15 +151,15 @@ void Running::kcfg_HashedControlPassword_textChanged( const QString & )
// <connections>
// <connection>
// <sender>SOCKSPolicy</sender>
-// <signal>contextMenuRequested(QListViewItem*,const QPoint&amp;,int)</signal>
+// <signal>contextMenuRequested(TQListViewItem*,const TQPoint&amp;,int)</signal>
// <receiver>Running</receiver>
-// <slot>SOCKSPolicy_contextMenuRequested(QListViewItem*,const QPoint&amp;,int)</slot>
+// <slot>SOCKSPolicy_contextMenuRequested(TQListViewItem*,const TQPoint&amp;,int)</slot>
// </connection>
// <connection>
// <sender>SOCKSBindAddressMany</sender>
-// <signal>contextMenuRequested(QListViewItem*,const QPoint&amp;,int)</signal>
+// <signal>contextMenuRequested(TQListViewItem*,const TQPoint&amp;,int)</signal>
// <receiver>Running</receiver>
-// <slot>SOCKSBindAddressMany_contextMenuRequested(QListViewItem*,const QPoint&amp;,int)</slot>
+// <slot>SOCKSBindAddressMany_contextMenuRequested(TQListViewItem*,const TQPoint&amp;,int)</slot>
// </connection>
// <connection>
// <sender>PushAdd</sender>
@@ -181,9 +181,9 @@ void Running::kcfg_HashedControlPassword_textChanged( const QString & )
// </connection>
// <connection>
// <sender>kcfg_HashedControlPassword</sender>
-// <signal>textChanged(const QString&amp;)</signal>
+// <signal>textChanged(const TQString&amp;)</signal>
// <receiver>Running</receiver>
-// <slot>kcfg_HashedControlPassword_textChanged(const QString&amp;)</slot>
+// <slot>kcfg_HashedControlPassword_textChanged(const TQString&amp;)</slot>
// </connection>
// <connection>
// <sender>kcfg_CookieAuthentication</sender>
@@ -204,12 +204,12 @@ void Running::kcfg_HashedControlPassword_textChanged( const QString & )
// <slots>
// <slot>PushAdd_clicked()</slot>
// <slot>PushAdd2_clicked()</slot>
// <slot>SOCKSBindAddressMany_contextMenuRequested( QListViewItem *, const QPoint &amp; point, int )</slot>
// <slot>slotDeleteEntry()</slot>
// <slot>SOCKSPolicy_contextMenuRequested( QListViewItem *, const QPoint &amp; point, int )</slot>
// <slot>slotDeletePolicyEntry()</slot>
// <slot>kcfg_DefaultRunningNormalOptions_toggled( bool state )</slot>
-// <slot>kcfg_HashedControlPassword_textChanged( const QString &amp; )</slot>
+// <slot>kcfg_HashedControlPassword_textChanged( const TQString &amp; )</slot>
// <slot>kcfg_CookieAuthentication_toggled( bool )</slot>
// <slot>kcfg_ClientOnly_toggled( bool state )</slot>
// </slots>
@@ -204,12 +204,12 @@ void Running::kcfg_HashedControlPassword_textChanged( const QString & )
// <slot>PushAdd_clicked()</slot>
// <slot>PushAdd2_clicked()</slot>
-// <slot>SOCKSBindAddressMany_contextMenuRequested( QListViewItem *, const QPoint &amp; point, int )</slot>
+// <slot>SOCKSBindAddressMany_contextMenuRequested( TQListViewItem *, const TQPoint &amp; point, int )</slot>
// <slot>slotDeleteEntry()</slot>
@@ -204,12 +204,12 @@ void Running::kcfg_HashedControlPassword_textChanged( const QString & )
// <slot>slotDeleteEntry()</slot>
-// <slot>SOCKSPolicy_contextMenuRequested( QListViewItem *, const QPoint &amp; point, int )</slot>
+// <slot>SOCKSPolicy_contextMenuRequested( TQListViewItem *, const TQPoint &amp; point, int )</slot>
// <slot>slotDeletePolicyEntry()</slot>
// <slot>kcfg_DefaultRunningNormalOptions_toggled( bool state )</slot>